==> core-android-debug-1.14.0-sources.jar: commonMain/io/dyte/core/controllers/MetaController.kt <==
package io.dyte.core.controllers

import io.dyte.core.network.info.ParticipantInfo

/**
 * Meta controller
 *
 * Contains meta details about the meeting,
 * example: [DyteMeetingInfoV1]
 *
 * @constructor Create empty Meta controller
 */
internal class MetaController(
  private val meetingInfo: MeetingInfo,
  controllerContainer: IControllerContainer
) : IMetaController, BaseController(controllerContainer) {
  private lateinit var participantInfo: ParticipantInfo
  private val meetingUserPeerId: String = controllerContainer.platformUtilsProvider.getPlatformUtils().getUuid()
  private lateinit var roomUuid: String
  override fun init() {
    meetingInfo.meetingId = controllerContainer.platformUtilsProvider.getPlatformUtils()
      .decodeAuthToken(meetingInfo.authToken)
    meetingInfo.isV2Meeting = meetingInfo.meetingId != null
  }

  override fun getDisplayName(): String {
    return participantInfo.name
  }

  override fun getRoomName(): String {
    return meetingInfo.getRoomName()
  }

  override fun getAuthToken(): String {
    return meetingInfo.authToken
  }

  override fun getBaseUrl(): String {
    return meetingInfo.baseUrl
  }

  override fun getBaseUrlWithoutVersion(): String {
    return meetingInfo.baseUrl.substring(0, meetingInfo.baseUrl.length-3)
  }

  override fun getPeerId(): String {
    return meetingUserPeerId
  }

  override fun getOrgId(): String {
    return participantInfo.organizationId
  }

  override fun getMeetingTitle(): String {
    return meetingInfo.meetingTitle ?: ""
  }

  override fun getMeetingStatedTimestamp(): String {
    return meetingInfo.meetingStartedAt ?: ""
  }

  override fun getRoomType(): String {
    return participantInfo.presetInfo.viewType
  }

  override fun setMeetingTitle(title: String) {
    meetingInfo.meetingTitle = title
  }

  override fun setMeetingStartedTimestamp(timestamp: String) {
    meetingInfo.meetingStartedAt = timestamp
  }

  override fun getMeetingId(): String {
    return meetingInfo.getRoomName()
  }

  override fun isV2AuthToken(): Boolean {
    return meetingInfo.isV2Meeting
  }

  override fun setParticipantInfo(participantInfo: ParticipantInfo) {
    this.participantInfo = participantInfo
  }

  override fun isWebinar(): Boolean {
    return participantInfo.presetInfo.viewType == "WEBINAR"
  }

  override fun isGroupCall(): Boolean {
    return participantInfo.presetInfo.viewType == "GROUP_CALL"
  }

  override fun isAudioEnabled(): Boolean {
    if (!meetingInfo.config.invalidateDefautlAudioSetting) {
      return meetingInfo.config.enableAudio
    }
    return  true
  }

  override fun isVideoEnabled(): Boolean {
    if (!meetingInfo.config.invalidateDefaultVideoSetting) {
      return meetingInfo.config.enableVideo
    }
    return  true
  }
  override fun getMeetingConfig(): MeetingConfig {
    return this.meetingInfo.config
  }

  override fun setRoomUuid(roomUuid: String) {
    this.roomUuid = roomUuid
  }

  override fun getRoomUuid(): String {
    return roomUuid
  }
}

internal data class MeetingInfo(
  val authToken: String,
  val config: MeetingConfig,
  val baseUrl: String
) {
  internal var isV2Meeting: Boolean = false
  internal var meetingId: String? = null
  internal var roomName: String? = null
  internal var viewType: String = "GROUP_CALL"
  internal var meetingTitle: String? = null
  internal var meetingStartedAt: String? = null

  fun getRoomName(): String {
    return if (isV2Meeting) requireNotNull(meetingId) else requireNotNull(roomName)
  }
}

data class MeetingConfig(
  val enableAudio: Boolean,
  val enableVideo: Boolean,
  var invalidateDefaultVideoSetting: Boolean,
  var invalidateDefautlAudioSetting: Boolean,
)

interface IMetaController {
  fun getPeerId(): String
  fun getBaseUrl(): String
  fun getBaseUrlWithoutVersion(): String
  fun getDisplayName(): String
  fun getRoomName(): String
  fun getAuthToken(): String
  fun getOrgId(): String

  fun setMeetingTitle(title: String)
  fun setMeetingStartedTimestamp(timestamp: String)

  fun getMeetingTitle(): String
  fun getMeetingStatedTimestamp(): String
  fun getRoomType(): String

  fun getMeetingId(): String
  fun getMeetingConfig(): MeetingConfig

  fun isWebinar(): Boolean
  fun isGroupCall(): Boolean

  fun isAudioEnabled(): Boolean

  fun isVideoEnabled(): Boolean

  fun setParticipantInfo(participantInfo: ParticipantInfo)

  fun isV2AuthToken(): Boolean

  fun setRoomUuid(roomUuid: String)

  fun getRoomUuid(): String
}

==> core-android-debug-1.16.2-sources.jar: commonMain/io/dyte/core/controllers/MetaController.kt <==
package io.dyte.core.controllers

import io.dyte.core.network.info.ParticipantInfo

/**
 * Meta controller
 *
 * Contains meta details about the meeting,
 * example: [DyteMeetingInfoV1]
 *
 * @constructor Create empty Meta controller
 */
internal class MetaController(
  private val meetingInfo: MeetingInfo,
  controllerContainer: IControllerContainer
) : IMetaController, BaseController(controllerContainer) {
  private lateinit var participantInfo: ParticipantInfo
  private val meetingUserPeerId: String =
    controllerContainer.platformUtilsProvider.getPlatformUtils().getUuid()
  private lateinit var roomUuid: String
  private var useHive: Boolean? = null

  override fun init() {
    meetingInfo.meetingId = controllerContainer.platformUtilsProvider.getPlatformUtils()
      .decodeAuthToken(meetingInfo.authToken)
    meetingInfo.isV2Meeting = meetingInfo.meetingId != null
  }

  override fun getDisplayName(): String {
    return participantInfo.name
  }

  override fun getRoomName(): String {
    return meetingInfo.getRoomName()
  }

  override fun getAuthToken(): String {
    return meetingInfo.authToken
  }

  override fun getBaseUrl(): String {
    return meetingInfo.baseUrl
  }

  override fun getBaseUrlWithoutVersion(): String {
    return meetingInfo.baseUrl.substring(0, meetingInfo.baseUrl.length - 3)
  }

  override fun getPeerId(): String {
    return meetingUserPeerId
  }

  override fun getOrgId(): String {
    return participantInfo.organizationId
  }

  override fun getMeetingTitle(): String {
    return meetingInfo.meetingTitle ?: ""
  }

  override fun getMeetingStatedTimestamp(): String {
    return meetingInfo.meetingStartedAt ?: ""
  }

  override fun getRoomType(): String {
    return participantInfo.presetInfo.viewType
  }

  override fun setMeetingTitle(title: String) {
    meetingInfo.meetingTitle = title
  }

  override fun setMeetingStartedTimestamp(timestamp: String) {
    meetingInfo.meetingStartedAt = timestamp
  }

  override fun getMeetingId(): String {
    return meetingInfo.getRoomName()
  }

  override fun isV2AuthToken(): Boolean {
    return meetingInfo.isV2Meeting
  }

  override fun setParticipantInfo(participantInfo: ParticipantInfo) {
    this.participantInfo = participantInfo
  }

  override fun isWebinar(): Boolean {
    return participantInfo.presetInfo.viewType == "WEBINAR"
  }

  override fun isGroupCall(): Boolean {
    return participantInfo.presetInfo.viewType == "GROUP_CALL"
  }

  override fun isAudioEnabled(): Boolean {
    if (!meetingInfo.config.invalidateDefautlAudioSetting) {
      return meetingInfo.config.enableAudio
    }
    return true
  }

  override fun isVideoEnabled(): Boolean {
    if (!meetingInfo.config.invalidateDefaultVideoSetting) {
      return meetingInfo.config.enableVideo
    }
    return true
  }

  override fun getMeetingConfig(): MeetingConfig {
    return this.meetingInfo.config
  }

  override fun setRoomUuid(roomUuid: String) {
    this.roomUuid = roomUuid
  }

  override fun getRoomUuid(): String {
    return roomUuid
  }

  override fun getIsHive(): Boolean {
    return useHive!!
  }

  override fun setIsHive(isHive: Boolean) {
    useHive = isHive
  }
}

internal data class MeetingInfo(
  val authToken: String,
  val config: MeetingConfig,
  val baseUrl: String
) {
  internal var isV2Meeting: Boolean = false
  internal var meetingId: String? = null
  internal var roomName: String? = null
  internal var viewType: String = "GROUP_CALL"
  internal var meetingTitle: String? = null
  internal var meetingStartedAt: String? = null

  fun getRoomName(): String {
    return if (isV2Meeting) requireNotNull(meetingId) else requireNotNull(roomName)
  }
}

data class MeetingConfig(
  val enableAudio: Boolean,
  val enableVideo: Boolean,
  var invalidateDefaultVideoSetting: Boolean,
  var invalidateDefautlAudioSetting: Boolean,
)

interface IMetaController {
  fun getPeerId(): String
  fun getBaseUrl(): String
  fun getBaseUrlWithoutVersion(): String
  fun getDisplayName(): String
  fun getRoomName(): String
  fun getAuthToken(): String
  fun getOrgId(): String

  fun setMeetingTitle(title: String)
  fun setMeetingStartedTimestamp(timestamp: String)

  fun getMeetingTitle(): String
  fun getMeetingStatedTimestamp(): String
  fun getRoomType(): String

  fun getMeetingId(): String
  fun getMeetingConfig(): MeetingConfig

  fun isWebinar(): Boolean
  fun isGroupCall(): Boolean

  fun isAudioEnabled(): Boolean

  fun isVideoEnabled(): Boolean

  fun setParticipantInfo(participantInfo: ParticipantInfo)

  fun isV2AuthToken(): Boolean

  fun setRoomUuid(roomUuid: String)

  fun getRoomUuid(): String

  fun getIsHive(): Boolean

  fun setIsHive(isHive: Boolean)
}
